@@ -20,13 +20,20 @@
 
 #![cfg_attr(not(target_env = "msvc"), feature(libc))]
 
-#[cfg(not(target_env = "msvc"))]
-extern crate libc;
+#[macro_use]
+mod macros;
 
-#[cfg(not(target_env = "msvc"))]
-mod libunwind;
-#[cfg(not(target_env = "msvc"))]
-pub use libunwind::*;
+cfg_if! {
+    if #[cfg(target_env = "msvc")] {
+        // no extra unwinder support needed
+    } else if #[cfg(all(target_arch = "wasm32", not(target_os = "emscripten")))] {
+        // no unwinder on the system!
+    } else {
+        extern crate libc;
+        mod libunwind;
+        pub use libunwind::*;
+    }
+}
 
 #[cfg(all(target_env = "musl", not(target_arch = "mips")))]
 #[link(name = "gcc_eh", cfg(target_feature = "crt-static"))]
